import 'reflect-metadata'
import {Container} from "typedi"
import {PostService} from "../services/post-service"
import express from "express"
import {body} from "express-validator"
import * as Validator from "validator"
import {hasValidationErrors} from "../includes"
import {JWTUserPayload} from "../types"

let postService = Container.get(PostService)

let postRouter = express.Router()
postRouter.post('/submit',
    body('content').notEmpty().withMessage('请输入内容')
        .escape(),
    body('image').isURL({host_whitelist: [/.*\.360buyimg\.com/]}).withMessage('仅支援*.360buyimg.com下的图片'),
    async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await postService.submit(req.user as JWTUserPayload,req.body.content, req.body.image))
    }
)

export {postRouter}
